@@ -1,6 +1,6 @@
 // This may look like C code, but it's really -*- C++ -*-
 /*
- * Copyright (C) 2008 Emweb bvba
+ * Copyright (C) 2008 Emweb bv, Herent, Belgium
  *
  * See the LICENSE file for terms of use.
  */
@@ -22,13 +22,13 @@ private:
   std::shared_ptr<Wt::WSortFilterProxyModel> filteredCocktails;
   std::shared_ptr<Wt::WSortFilterProxyModel> filteredSortedCocktails;
 
-  std::unique_ptr<WWidget> tables();
-  std::unique_ptr<WWidget> trees();
-  std::unique_ptr<WWidget> treeTables();
-  std::unique_ptr<WWidget> tableViews();
-  std::unique_ptr<WWidget> treeViews();
-  std::unique_ptr<WWidget> itemModels();
-  std::unique_ptr<WWidget> proxyModels();
+  std::unique_ptr<Wt::WWidget> tables();
+  std::unique_ptr<Wt::WWidget> trees();
+  std::unique_ptr<Wt::WWidget> treeTables();
+  std::unique_ptr<Wt::WWidget> tableViews();
+  std::unique_ptr<Wt::WWidget> treeViews();
+  std::unique_ptr<Wt::WWidget> itemModels();
+  std::unique_ptr<Wt::WWidget> proxyModels();
 
   Wt::WStringListModel *stringList_;
 
